Bender<-function(phrase="CorReg rules !",a=0,b=0,c=0){
   if(!is.null(c) & !try(c<4) & is.null(try(dim(c)))){
      inkei(a,b,c)
   }else{cat( "\n
                  o
                  |
                ,'~'.
               /     \\
              |   ____|_
              |  '___,,_'         .----------------.
              |  ||(o |o)|       ( ",phrase," )
              |   -------         ,----------------'
              |  _____|         -'
              \\  '####,
               -------
             /________\\
           (  )        |)
           '_ ' ,------|\\         _
          /_ /  |      |_\\        ||
         /_ /|  |     o| _\\      _|| 
        /_ / |  |      |\\ _\\____//' |
       (  (  |  |      | (_,_,_,____/
        \\ _\\ |   ------|        
         \\ _\\|_________|
          \\ _\\ \\__\\\\__\\
          |__| |__||__|
       ||/__/  |__||__|
               |__||__|
               |__||__|
               /__)/__)
              /__//__/
             /__//__/
            /__//__/.
          .'    '.   '.
         (_CorReg____)____)
  ")
  } 
}